{
  This program shows how to create a DlgWindow that
  has a BORDLG style and a custom icon. The key is
  override both the GetWindowClass and GetClassname
  functions. Give the class a name with the
  form BorDlg_XXX, where the letters XXX are user
  defined. For instance, you might call your class
  BorDlg_MyClass.

  When you are in the resource WorkShop, you want to
  be sure to give you dialog the same class name:

  DIALOG_1 DIALOG 18, 18, 168, 92
  CLASS "BorDlg_MyClass"
  CAPTION "DIALOG_1"

  In these cases, you should assign your program an
  icon in the normal fashion, as part of your
  GetWindowClass method:

  AWndClass.hIcon := LoadIcon(HInstance, 'ICON_1');

  A complete example is shown below, with the resource
  itself listed after the code. I have included the
  textual description of the icon which was produced
  by the Resource Workshop. However, any valid icon
  will do, there is no need to use the icon I've
  included here. In other words, if you have
  retrieved this file in digital form then you can
  cut and paste the RC file shown below, using
  it unchanged in the resource workshop. If you
  got this from a fax, then make up your own icon,
  or borrow one from another program.
}

program DlgWind;
{ The RC file for this program is listed below. }

uses WinTypes, WinProcs, owINDOWS, odIALOGS, BWCC;
{$R DlgWndic}

type
  TMyApplication = object(TApplication)
    procedure InitMainWindow; virtual;
  end;

type
  PMyDialog = ^TMyDialog;
  TMyDialog = object(TDlgWindow)
    procedure GetWindowClass(var AWndClass: TWndClass); virtual;
    function GetClassName: PChar; virtual;
  end;

{--------------------------------------------------}
{ TMyDialog's method implementations:              }
{--------------------------------------------------}

function TMyDialog.GetClassName: PChar;
begin
  GetClassName := 'Bordlg_IC';
end;

procedure TMyDialog.GetWindowClass(var AWndClass: TWndClass);
begin
  inherited GetWindowClass(AWndClass);
  AWndClass.hIcon := LoadIcon(HInstance, 'ICON_1');
end;

{--------------------------------------------------}
{ TMyApplication's method implementations:         }
{--------------------------------------------------}

procedure TMyApplication.InitMainWindow;
begin
  MainWindow := New(PMyDialog, Init(nil, 'Dialog_1'));
end;

{--------------------------------------------------}
{ Main program:                                    }
{--------------------------------------------------}

var
  MyApp: TMyApplication;

begin
  MyApp.Init('MyProgram');
  MyApp.Run;
  MyApp.Done;
end.


DIALOG_1 DIALOG 18, 18, 168, 92
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU | WS_MINIMIZEBOX
CLASS "BorDlg_IC"
CAPTION "DIALOG_1"
BEGIN
	ICON "ICON_1", -1, 80, 33, 16, 16
	CONTROL "", 101, "BorShade", 1 | WS_CHILD | WS_VISIBLE, 17, 29, 136, 40
	CONTROL "A thing of beauty is a joy forever.", 102, "EDIT", ES_LEFT | WS_CHILD | WS_VISIBLE | WS_BORDER | WS_TABSTOP, 30, 52, 111, 12
END


ICON_1 ICON 
BEGIN
	'00 00 01 00 01 00 20 20 10 00 00 00 00 00 E8 02'
	'00 00 16 00 00 00 28 00 00 00 20 00 00 00 40 00'
	'00 00 01 00 04 00 00 00 00 00 00 02 00 00 00 00'
	'00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00'
	'00 00 00 00 80 00 00 80 00 00 00 80 80 00 80 00'
	'00 00 80 00 80 00 80 80 00 00 C0 C0 C0 00 80 80'
	'80 00 00 00 FF 00 00 FF 00 00 00 FF FF 00 FF 00'
	'00 00 FF 00 FF 00 FF FF 00 00 FF FF FF 00 00 00'
	'00 00 00 00 00 00 00 BB 00 00 00 00 00 00 00 00'
	'00 00 00 00 00 00 00 B0 B0 00 00 00 00 00 00 00'
	'00 00 00 00 00 00 00 B0 B0 00 00 00 00 00 00 00'
	'00 00 00 00 00 00 00 B0 0B 0B 00 00 00 00 00 00'
	'00 00 00 00 00 00 00 B0 00 BB B0 00 00 00 00 00'
	'00 00 00 00 00 00 00 B0 00 0B B0 00 00 00 00 00'
	'00 00 00 00 00 00 00 B0 0B BB B0 00 00 00 00 00'
	'00 00 00 00 00 00 0B BB B0 00 B0 00 00 00 00 00'
	'00 00 00 00 00 00 B0 0B 00 00 BB 00 00 00 00 00'
	'00 00 00 00 00 00 B0 0B 00 00 0B B0 00 00 00 00'
	'00 BB BB BB 00 00 B0 0B 00 00 0B B0 00 00 00 00'
	'00 0B BB BB BB BB 0B 0B 00 00 00 BB 00 00 00 00'
	'00 00 00 00 BB BB BB 0B 00 00 00 BB 00 00 00 00'
	'0B 00 00 00 00 00 BB BB 00 00 00 BB 00 00 00 0B'
	'0B B0 0B BB BB BB BB BB B0 00 00 00 00 00 00 0B'
	'B0 BB 0B 00 00 00 00 00 BB 00 00 00 00 00 00 00'
	'0B BB BB 00 00 00 00 00 BB 00 00 00 00 00 00 00'
	'00 0B BB BB B0 00 00 00 BB 00 00 00 00 00 00 00'
	'00 00 BB 0B BB BB B0 00 BB B0 00 00 00 00 00 00'
	'00 00 B0 BB 0B BB 0B BB BB B0 00 00 00 00 00 00'
	'00 00 B0 00 BB 0B BB BB BB 0B 00 00 00 00 00 00'
	'00 0B 00 00 00 B0 BB B0 0B 0B 00 00 00 00 00 00'
	'00 0B 00 00 00 0B BB 0B BB BB B0 00 00 00 00 00'
	'00 BB BB BB BB BB BB BB BB B0 BB 00 00 00 00 00'
	'0B BB B0 00 00 0B 00 00 0B 00 0B B0 00 00 0B BB'
	'BB BB BB BB BB BB BB BB BB 00 00 BB 00 00 0B BB'
	'BB B0 00 0B B0 0B 00 00 00 00 00 0B 00 00 00 0B'
	'BB 00 00 00 0B 00 00 00 00 00 00 00 00 00 00 00'
	'00 BB 00 00 00 BB 00 00 00 00 00 00 00 00 00 BB'
	'BB BB BB BB BB BB BB 00 00 00 00 00 00 00 00 00'
	'00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00'
	'00 00 00 00 00 00 00 00 00 00 00 00 00 00 FF FF'
	'CF FF FF FF D7 FF FF FF D7 FF FF FF DA FF FF FF'
	'DC 7F FF FF DE 7F FF FF D8 7F FF FF 87 7F FF FF'
	'6F 3F FF FF 6F 9F FC 0F 6F 9F FE 00 AF CF FF F0'
	'2F CF FB FF 0F CF E9 80 07 FF E4 BF F3 FF F8 3F'
	'F3 FF FE 07 F3 FF FF 20 71 FF FF 48 81 FF FF 72'
	'02 FF FE FD 1A FF FE FE 20 7F FC 00 01 3F F8 7E'
	'FB 9F 80 00 03 CF 81 E6 FF EF E3 FB FF FF FC FC'
	'FF FF C0 00 3F FF FF FF FF FF FF FF FF FF'
END

